pub fn model_reference(mechanism: PhysicalMechanism) -> &'static strExpand description
Map a reason code to the primary physical model reference.
Returns a human-readable model name for documentation and audit trails.
pub fn model_reference(mechanism: PhysicalMechanism) -> &'static strMap a reason code to the primary physical model reference.
Returns a human-readable model name for documentation and audit trails.