pub struct DetectabilitySummary {
pub class: DetectabilityClass,
pub semantic: SemanticStatus,
pub band: DetectionStrengthBand,
pub bound: DetectabilityBound,
pub post_crossing_duration: u32,
pub post_crossing_fraction: f32,
pub peak_margin_after_crossing: f32,
pub boundary_proximate_crossing: bool,
}Expand description
Full detectability summary for one observation window.
All fields are deterministically computed from the residual norm history. No probability model is required or assumed.
Fields
class: DetectabilityClassCoarse interpretation class.
semantic: SemanticStatusFine semantic status.
band: DetectionStrengthBandDashboard strength band.
bound: DetectabilityBoundDeterministic τ_upper bound (if computable).
post_crossing_duration: u32Number of samples spent outside envelope since first crossing. Zero if no crossing has occurred.
post_crossing_fraction: f32Fraction of recent W samples spent outside envelope (0..=1).
peak_margin_after_crossing: f32Maximum normalised excess (‖r‖ − ρ) / ρ observed since first crossing.
boundary_proximate_crossing: boolTrue if the crossing occurred within the “early window.”